#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/5/2 12:16
# @Author  : justin.郑 3907721@qq.com
# @File    : __init__.py.py
# @Desc    :

from web_extractor.test import (
    cs_test
)